@@ -17,7 +17,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
-__all__ = ["__author__", "__description__", "__license__", "__url__", "__version__"]
+__all__ = [
+    "__author__",
+    "__author_email__",
+    "__description__",
+    "__license__",
+    "__url__",
+    "__version__",
+]
 
 
 def git_describe():
@@ -32,7 +39,8 @@ def git_describe():
 
 
 __author__ = "Rémi Duraffort"
+__author_email__ = "remi.duraffort@linaro.org"
 __description__ = "LAVA XML-RPC command line interface"
 __license__ = "AGPLv3+"
 __url__ = "https://git.lavasoftware.org/lava/lavacli"
-__version__ = "0.9.7"
+__version__ = "0.9.8"
