@@ -260,7 +260,7 @@ def handle_aliases(proxy, options):
         if options.output_format == "json":
             print(json.dumps(aliases))
         elif options.output_format == "yaml":
-            print(yaml.dump(aliases).rstrip("\n"))
+            print(yaml.dump(aliases, default_flow_style=None).rstrip("\n"))
         else:
             print("Aliases:")
             for alias in aliases:
@@ -287,7 +287,7 @@ def handle_list(proxy, options):
     if options.output_format == "json":
         print(json.dumps(device_types))
     elif options.output_format == "yaml":
-        print(yaml.dump(device_types).rstrip("\n"))
+        print(yaml.dump(device_types, default_flow_style=None).rstrip("\n"))
     else:
         print("Device-Types:")
         for dt in device_types:
@@ -301,7 +301,7 @@ def handle_show(proxy, options):
     if options.output_format == "json":
         print(json.dumps(dt))
     elif options.output_format == "yaml":
-        print(yaml.dump(dt).rstrip("\n"))
+        print(yaml.dump(dt, default_flow_style=None).rstrip("\n"))
     else:
         print("name            : %s" % dt["name"])
         print("description     : %s" % dt["description"])
