@@ -370,7 +370,7 @@ def handle_list(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(jobs))
     elif options.output_format == "yaml":
-        print(yaml.dump(jobs).rstrip("\n"))
+        print(yaml.dump(jobs, default_flow_style=None).rstrip("\n"))
     else:
         print(
             "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
@@ -568,7 +568,7 @@ def handle_queue(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(data))
     elif options.output_format == "yaml":
-        print(yaml.dump(data).rstrip("\n"))
+        print(yaml.dump(data, default_flow_style=None).rstrip("\n"))
     else:
         print(
             "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
@@ -687,7 +687,7 @@ def handle_show(proxy, options, config):
         job["submit_time"] = job["submit_time"].value
         job["start_time"] = job["start_time"].value
         job["end_time"] = job["end_time"].value
-        print(yaml.dump(job).rstrip("\n"))
+        print(yaml.dump(job, default_flow_style=None).rstrip("\n"))
     else:
         print("id          : %s" % job["id"])
         print("description : %s" % job["description"])
