@@ -68,7 +68,7 @@ def handle(proxy, options, _):
     if options.output_format == "json":
         print(json.dumps(results))
     elif options.output_format == "yaml":
-        print(yaml.dump(results).rstrip("\n"))
+        print(yaml.dump(results, default_flow_style=None).rstrip("\n"))
     else:
         # Only print the result
         if options.test_case is not None:
