@@ -18,6 +18,7 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import re
+import xmlrpc.client
 import yaml
 
 
@@ -42,9 +43,15 @@ def parse_version(version):
     return (int(res["major"]), int(res["minor"]))
 
 
-def loader():
+def loader(safe=True):
     try:
-        return yaml.CLoader
+        return yaml.CSafeLoader if safe else yaml.CLoader
     except AttributeError:
         # TODO log a warning on stderr
-        return yaml.Loader
+        return yaml.SafeLoader if safe else yaml.Loader
+
+
+def exc2str(exc):
+    if isinstance(exc, xmlrpc.client.ProtocolError):
+        return exc.errmsg
+    return str(exc)
