@@ -904,6 +904,174 @@ def test_jobs_logs_raw_filter(setup, monkeypatch, capsys):
     )
 
 
+def test_jobs_queue(setup, monkeypatch, capsys):
+    version = "2019.01"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "queue"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.jobs.queue",
+                "args": (None, 0, 25),
+                "ret": [
+                    {
+                        "id": 12,
+                        "description": None,
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                    {
+                        "id": 14,
+                        "description": "qemu health",
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                ],
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert (  # nosec
+        capsys.readouterr()[0]
+        == """Jobs (from 1 to 25):
+* 12: lava-health () - qemu
+* 14: lava-health (qemu health) - qemu
+"""
+    )
+
+
+def test_jobs_queue_json(setup, monkeypatch, capsys):
+    version = "2019.01"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "queue", "--json"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.jobs.queue",
+                "args": (None, 0, 25),
+                "ret": [
+                    {
+                        "id": 12,
+                        "description": None,
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                    {
+                        "id": 14,
+                        "description": "qemu health",
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                ],
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert json.loads(capsys.readouterr()[0]) == [  # nosec
+        {
+            "id": 12,
+            "description": None,
+            "requested_device_type": "qemu",
+            "submitter": "lava-health",
+        },
+        {
+            "id": 14,
+            "description": "qemu health",
+            "requested_device_type": "qemu",
+            "submitter": "lava-health",
+        },
+    ]
+
+
+def test_jobs_queue_yaml(setup, monkeypatch, capsys):
+    version = "2019.01"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "queue", "--yaml"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.jobs.queue",
+                "args": (None, 0, 25),
+                "ret": [
+                    {
+                        "id": 12,
+                        "description": None,
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                    {
+                        "id": 14,
+                        "description": "qemu health",
+                        "requested_device_type": "qemu",
+                        "submitter": "lava-health",
+                    },
+                ],
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert (  # nosec
+        capsys.readouterr()[0]
+        == """- {description: null, id: 12, requested_device_type: qemu, submitter: lava-health}
+- {description: qemu health, id: 14, requested_device_type: qemu, submitter: lava-health}
+"""
+    )
+
+
+def test_jobs_queue_filtering(setup, monkeypatch, capsys):
+    version = "2019.01"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "queue", "qemu"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {"request": "scheduler.jobs.queue", "args": (["qemu"], 0, 25), "ret": []},
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "Jobs (from 1 to 25):\n"  # nosec
+
+    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "queue", "qemu", "panda"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.jobs.queue",
+                "args": (["qemu", "panda"], 0, 25),
+                "ret": [],
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "Jobs (from 1 to 25):\n"  # nosec
+
+    version = "2019.01"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "jobs", "queue", "--start", "1", "--limit", "3", "qemu"],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {"request": "scheduler.jobs.queue", "args": (["qemu"], 1, 3), "ret": []},
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "Jobs (from 2 to 4):\n"  # nosec
+
+
 def test_jobs_resubmit(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "resubmit", "1234"])
