@@ -161,6 +161,75 @@ def test_workers_config_set_error(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Unable to store worker configuration\n"  # nosec
 
 
+def test_workers_env_get(setup, monkeypatch, capsys):
+    version = "2019.6"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "workers", "env", "get", "worker01"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.get_env",
+                "args": ("worker01",),
+                "ret": "env content",
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "env content\n"  # nosec
+
+
+def test_workers_env_set(setup, monkeypatch, capsys, tmpdir):
+    version = "2019.6"
+    with (tmpdir / "env.yaml").open("w") as f_conf:
+        f_conf.write("env content")
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env", "set", "worker01", str(tmpdir / "env.yaml")],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env",
+                "args": ("worker01", "env content"),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
+def test_workers_env_set_error(setup, monkeypatch, capsys, tmpdir):
+    version = "2019.6"
+    with (tmpdir / "env.yaml").open("w") as f_conf:
+        f_conf.write("env content")
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["lavacli", "workers", "env", "set", "worker01", str(tmpdir / "env.yaml")],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.workers.set_env",
+                "args": ("worker01", "env content"),
+                "ret": False,
+            },
+        ],
+    )
+    assert main() == 1  # nosec
+    assert capsys.readouterr()[0] == "Unable to store worker environment\n"  # nosec
+
+
 def test_workers_list(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(sys, "argv", ["lavacli", "workers", "list"])
